# HostPermissions

Host's properties

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**upstream_host** | **str** | Upstream hostname | [optional] 
**app_id** | **str** | The application id corresponding to this host. | [optional] [readonly] 
**admin_org_id** | **str** | The organisation id corresponding to the organisation which administers the instance granted permissions by this.  | [optional] [readonly] 
**allowed_list** | [**[RenderedRule]**](RenderedRule.md) | List of rules | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


